@@ -79,6 +79,9 @@
   #if defined(__GNUC__) && !defined(__riscos) && !defined(__convex__)
     #undef alloca
     #define alloca  __builtin_alloca
+  #elif defined(_MSC_VER)
+    #include <malloc.h>
+    #define alloca  _alloca
   #elif defined(HAVE_ALLOCA_H) || defined(__riscos)
     #include <alloca.h>
     #ifndef alloca // Sometimes `alloca' is defined as a macro...
